(fressian-serializer)(fressian-serializer opts)Fressian serializer for Apache Kafka. Use for serializing Kafka values.
Notes: You may pass any of the built-in Fressian options via the opts map, using the 1-arity version of this function.
Fressian serializer for Apache Kafka. Use for serializing Kafka values. > Notes: You may pass any of the built-in Fressian options via the opts map, using the 1-arity version of this function.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |